@@ -226,11 +226,9 @@ def page(date, dpp=2):
     # creates a page (2 days) of tables
 
     if dpp > 1:
-        str2 = r'''\textbf{{{} to {}}}
-'''.format(date.strftime("%Y %B %d"),(date+timedelta(days=dpp-1)).strftime("%b. %d"))
+        str2 = r'''\textbf{{{} to {}}}'''.format(date.strftime("%Y %B %d"),(date+timedelta(days=dpp-1)).strftime("%b. %d"))
     else:
-        str2 = r'''\textbf{{{}}}
-'''.format(date.strftime("%Y %B %d"))
+        str2 = r'''\textbf{{{}}}'''.format(date.strftime("%Y %B %d"))
 
     page = r'''
 % ------------------ N E W   P A G E ------------------
@@ -238,7 +236,7 @@ def page(date, dpp=2):
 \sffamily
 \noindent
 \begin{{flushright}}
-\textbf{{{}}}%
+{}%
 \end{{flushright}}\par
 \begin{{scriptsize}}
 '''.format(str2)
