@@ -189,17 +189,18 @@ def suntab(date, n):
 
         vd = alma_ephem.sun_moon_SD(dfl)
         tab = tab + r'''\hline
-\rule{{0pt}}{{2.4ex}} & \multicolumn{{1}}{{c}}{{SD={}$'$}} & \multicolumn{{1}}{{c|}}{{\textit{{d}}\,=\,{}$'$}}\\
+\rule{{0pt}}{{2.4ex}} & 
+\multicolumn{{1}}{{c}}{{SD={}$'$}} & 
+\multicolumn{{1}}{{c|}}{{\textit{{d}}\,=\,{}$'$}}\\
 \hline
 '''.format(vd[1],vd[0])
-        if n < 2:
+        if n > 1:
             # add space between tables...
             tab = tab + r'''\multicolumn{1}{c}{}\\[-0.5ex]'''
         n -= 1
         dfl += 1
 
-    tab = tab + r'''
-\end{tabular*}'''
+    tab = tab + r'''\end{tabular*}'''
     return tab
 
 # >>>>>>>>>>>>>>>>>>>>>>>>
@@ -286,8 +287,8 @@ def suntabm(date, n):
                 dhr += ephem.hour
 
         vd = alma_ephem.sun_moon_SD(dfl)
-        tab = tab + r'''\cmidrule{{2-3}}
-& \multicolumn{{1}}{{c}}{{\scriptsize{{SD\,=\,{}$'$}}}} & \multicolumn{{1}}{{c}}{{\footnotesize{{\textit{{d}}\,=\,{}$'$}}}}\\
+        tab = tab + r'''\cmidrule{{2-3}} & 
+\multicolumn{{1}}{{c}}{{\scriptsize{{SD\,=\,{}$'$}}}} & \multicolumn{{1}}{{c}}{{\footnotesize{{\textit{{d}}\,=\,{}$'$}}}}\\
 \cmidrule{{2-3}}'''.format(vd[1],vd[0])
         if n > 1:
             # add space between tables...
@@ -307,11 +308,9 @@ def suntabm(date, n):
 def page(date, dpp=15):
 
     if dpp > 1:
-        str2 = r'''\textbf{{{} to {}}}
-'''.format(date.strftime("%Y %B %d"),(date+timedelta(days=dpp-1)).strftime("%b. %d"))
+        str2 = r'''\textbf{{{} to {}}}'''.format(date.strftime("%Y %B %d"),(date+timedelta(days=dpp-1)).strftime("%b. %d"))
     else:
-        str2 = r'''\textbf{{{}}}
-'''.format(date.strftime("%Y %B %d"))
+        str2 = r'''\textbf{{{}}}'''.format(date.strftime("%Y %B %d"))
 
     # creates a page(15 days) of the Sun almanac
     page = r'''
@@ -320,7 +319,7 @@ def page(date, dpp=15):
 \sffamily
 \noindent
 \begin{{flushright}}
-\textbf{{{}}}\par
+{}\par
 \end{{flushright}}
 \begin{{scriptsize}}
 '''.format(str2)
@@ -515,7 +514,7 @@ def sunalmanac(first_day, dtp, dfra):
     \begin{description}[leftmargin=5.5em,style=nextline]\footnotesize
     \item[Disclaimer:] These are computer generated tables - use them at your own risk.
     The accuracy has been checked as well as possible, but cannot be guaranteed.
-    This means I cannot be held liable if you get lost on the oceans because of errors in this publication.
+    The author claims no liability for any consequences arising from use of these tables.
     Besides, this publication only contains sun tables: an official version of the Nautical Almanac is indispensable.
     \end{description}
 \end{titlepage}
